==> jc-1.4.0.tar.gz: javax/swing/tree/AbstractLayoutCache__24NodeDimensions.c <==
// public abstract class javax.swing.tree.AbstractLayoutCache$NodeDimensions

// class file dependencies
// @dep_class 553e6310bdd97411 java_awt_Rectangle
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 4152fdd77f66f9d0 javax_swing_tree_AbstractLayoutCache
// @dep_class b132529ee8250685 javax_swing_tree_AbstractLayoutCache__24NodeDimensions

// header file dependencies
// @dep_header java_awt_Rectangle
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_tree_AbstractLayoutCache
// @dep_header javax_swing_tree_AbstractLayoutCache__24NodeDimensions

#include "jc_defs.h"

#include "java/awt/Rectangle.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/tree/AbstractLayoutCache.h"
#include "javax/swing/tree/AbstractLayoutCache__24NodeDimensions.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_tree_AbstractLayoutCache__24NodeDimensions, _init$52f4ad9f2989aeee);

void
_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object *this)
{
	struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(64);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract java.awt.Rectangle getNodeDimensions(java.lang.Object, int, int, boolean, java.awt.Rectangle)
//

static const unsigned char _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$param_ptypes$getNodeDimensions$12b4497979399f42[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_INT, _JC_TYPE_INT, _JC_TYPE_BOOLEAN, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$param_types$getNodeDimensions$12b4497979399f42[] = {
	&_jc_java_lang_Object$type,
	&_jc_int$prim$type,
	&_jc_int$prim$type,
	&_jc_boolean$prim$type,
	&_jc_java_awt_Rectangle$type
};

_jc_method _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method_info$getNodeDimensions$12b4497979399f42 = {
	.name=			"getNodeDimensions",
	.signature=		"(Ljava/lang/Object;IIZLjava/awt/Rectangle;)Ljava/awt/Rectangle;",
	.class=			&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$type,
	.param_types=		&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$param_types$getNodeDimensions$12b4497979399f42,
	.return_type=		&_jc_java_awt_Rectangle$type,
	.param_ptypes=		&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$param_ptypes$getNodeDimensions$12b4497979399f42,
	.signature_hash=	_JC_JLONG(0x12b4497979399f42),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method$getNodeDimensions$12b4497979399f42,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtable, javax_swing_tree_AbstractLayoutCache__24NodeDimensions.getNodeDimensions$12b4497979399f42) / sizeof(void *),
	.num_parameters=	5,
};

_jc_java_awt_Rectangle$object *
_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method$getNodeDimensions$12b4497979399f42(_jc_env *const env, _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object *this, _jc_java_lang_Object$object *param0, jint param1, jint param2, jboolean param3, _jc_java_awt_Rectangle$object *param4)
{
	_JC_ABSTRACT_METHOD(env, &_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method_info$getNodeDimensions$12b4497979399f42);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$methods[] = {
	&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method_info$getNodeDimensions$12b4497979399f42
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$instanceof_hash_bucket_5[] = {
	&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[5]=	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$instanceof_hash_bucket_5,
	[113]=	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$class_depends[] = {
	{ "java/awt/Rectangle",	_JC_JLONG(0x553e6310bdd97411) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "javax/swing/tree/AbstractLayoutCache",	_JC_JLONG(0x4152fdd77f66f9d0) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtype _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$type = {
    .type= {
	.name=			"javax/swing/tree/AbstractLayoutCache$NodeDimensions",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xb132529ee8250685),
		.source_file=		"AbstractLayoutCache.java",
		.instance_size=		sizeof(_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$refs) + sizeof(_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$methods) / sizeof(*_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$methods),
		.methods=		_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$methods,
		.instanceof_hash_table=	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$instanceof_hash_table,
		.outer_class=		&_jc_javax_swing_tree_AbstractLayoutCache$type,
		.num_class_depends=		sizeof(_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$class_depends) / sizeof(*_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$class_depends),
		.class_depends=		_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_tree_AbstractLayoutCache__24NodeDimensions= {
	    .getNodeDimensions$12b4497979399f42=
		&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method$getNodeDimensions$12b4497979399f42,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/swing/tree/AbstractLayoutCache__24NodeDimensions.c <==
// public abstract class javax.swing.tree.AbstractLayoutCache$NodeDimensions

// class file dependencies
// @dep_class 553e6310bdd97411 java_awt_Rectangle
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 4152fdd77f66f9d0 javax_swing_tree_AbstractLayoutCache
// @dep_class b132529ee8250685 javax_swing_tree_AbstractLayoutCache__24NodeDimensions

// header file dependencies
// @dep_header java_awt_Rectangle
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_tree_AbstractLayoutCache
// @dep_header javax_swing_tree_AbstractLayoutCache__24NodeDimensions

#include "jc_defs.h"

#include "java/awt/Rectangle.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/tree/AbstractLayoutCache.h"
#include "javax/swing/tree/AbstractLayoutCache__24NodeDimensions.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_tree_AbstractLayoutCache__24NodeDimensions, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object *this)
{
	struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(64);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract java.awt.Rectangle getNodeDimensions(java.lang.Object, int, int, boolean, java.awt.Rectangle)
//

static const unsigned char _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$param_ptypes$getNodeDimensions$12b4497979399f42[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_INT, _JC_TYPE_INT, _JC_TYPE_BOOLEAN, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$param_types$getNodeDimensions$12b4497979399f42[] = {
	&_jc_java_lang_Object$type,
	&_jc_int$prim$type,
	&_jc_int$prim$type,
	&_jc_boolean$prim$type,
	&_jc_java_awt_Rectangle$type
};

_jc_method _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method_info$getNodeDimensions$12b4497979399f42 = {
	.name=			"getNodeDimensions",
	.signature=		"(Ljava/lang/Object;IIZLjava/awt/Rectangle;)Ljava/awt/Rectangle;",
	.class=			&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$type,
	.param_types=		&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$param_types$getNodeDimensions$12b4497979399f42,
	.return_type=		&_jc_java_awt_Rectangle$type,
	.param_ptypes=		&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$param_ptypes$getNodeDimensions$12b4497979399f42,
	.signature_hash=	_JC_JLONG(0x12b4497979399f42),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method$getNodeDimensions$12b4497979399f42,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtable, javax_swing_tree_AbstractLayoutCache__24NodeDimensions.getNodeDimensions$12b4497979399f42) / sizeof(void *),
	.num_parameters=	5,
};

_jc_java_awt_Rectangle$object * _JC_JCNI_ATTR
_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method$getNodeDimensions$12b4497979399f42(_jc_env *const env, _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object *this, _jc_java_lang_Object$object *param0, jint param1, jint param2, jboolean param3, _jc_java_awt_Rectangle$object *param4)
{
	_JC_ABSTRACT_METHOD(env, &_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method_info$getNodeDimensions$12b4497979399f42);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$methods[] = {
	&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method_info$getNodeDimensions$12b4497979399f42
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$instanceof_hash_bucket_5[] = {
	&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[5]=	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$instanceof_hash_bucket_5,
	[101]=	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$class_depends[] = {
	{ "java/awt/Rectangle",	_JC_JLONG(0x553e6310bdd97411) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "javax/swing/tree/AbstractLayoutCache",	_JC_JLONG(0x4152fdd77f66f9d0) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtype _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$type = {
    .type= {
	.name=			"javax/swing/tree/AbstractLayoutCache$NodeDimensions",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xb132529ee8250685),
		.source_file=		"AbstractLayoutCache.java",
		.instance_size=		sizeof(_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$refs) + sizeof(_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$methods) / sizeof(*_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$methods),
		.methods=		_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$methods,
		.instanceof_hash_table=	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$instanceof_hash_table,
		.outer_class=		&_jc_javax_swing_tree_AbstractLayoutCache$type,
		.num_class_depends=		sizeof(_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$class_depends) / sizeof(*_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$class_depends),
		.class_depends=		_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_tree_AbstractLayoutCache__24NodeDimensions= {
	    .getNodeDimensions$12b4497979399f42=
		&_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method$getNodeDimensions$12b4497979399f42,
	},
    }
};
